# coding: utf-8

"""
    Versatile Data Kit Control Service API

    The Data Jobs API of Versatile Data Kit Control Service. Data Jobs allows Data Engineers to implement automated pull ingestion (E in ELT) and batch data transformation into a database (T in ELT). See also https://github.com/vmware/versatile-data-kit/wiki/Introduction The API has resource-oriented URLs, JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs. The API enables creating, deploying, managing and executing Data Jobs in the runtime environment.<br> <br> ![](https://github.com/vmware/versatile-data-kit/wiki/vdk-data-job-lifecycle-state-diagram.png) <br> The API reflects the usual Data Job Development lifecycle:<br> <li> Create a new data job (webhook to further configure the job, e.g authorize its creation, setup permissions, etc). <li> Download keytab. Develop and run the data job locally. <li> Deploy the data job in cloud runtime environment to run on a scheduled basis. <br><br> If Authentication is enabled, pass OAuth2 access token in HTTP header 'Authorization: Bearer [access-token-here]' (https://datatracker.ietf.org/doc/html/rfc6750). <br The API promotes some best practices (inspired by https://12factor.net): <li> Explicitly declare and isolate dependencies. <li> Strict separation of configurations from code. Configurations vary substantially across deploys, code does not. <li> Separation between the build, release/deploy, and run stages. <li> Data Jobs are stateless and share-nothing processes. Any data that needs to be persisted must be stored in a stateful backing service (e.g IProperties). <li> Implementation is assumed to be atomic and idempotent - should be OK for a job to fail somewhere in the middle; subsequent restart should not cause data corruption. <li> Keep development, staging, and production as similar as possible. <br><br> <b>API Evolution</b><br> In the following sections, there are some terms that have a special meaning in the context of the APIs. <br><br> <li> <i>Stable</i> - The implementation of the API has been battle-tested (has been in production for some time). The API is a subject to semantic versioning model and will follow deprecation policy. <li> <i>Experimental</i> - May disappear without notice and is not a subject to semantic versioning. Implementation of the API is not considered stable nor well tested. Generally this is given to clients to experiment within testing environment. Must not be used in production. <li> <i>Deprecated</i> - API is expected to be removed within next one or two major version upgrade. The deprecation notice/comment will say when the API will be removed and what alternatives should be used instead.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import taurus_datajob_api
from taurus_datajob_api.models.data_job_page import DataJobPage  # noqa: E501
from taurus_datajob_api.rest import ApiException

class TestDataJobPage(unittest.TestCase):
    """DataJobPage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DataJobPage
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DataJobPage`
        """
        model = taurus_datajob_api.models.data_job_page.DataJobPage()  # noqa: E501
        if include_optional :
            return DataJobPage(
                content = {"application/json":[{"jobName":"starshot-processing-vmc-fact-daily","config":{"team":"starshot","description":"Data Job responsible for transforming vmc related fact tables on daily basis","schedule":{"scheduleCron":"5 0 * 8 *","nextRun":1618914371},"sourceUrl":"https://github.com/product-analytics/data-jobs/tree/master/starshot-processing-vmc-fact-daily","contacts":{"notifiedOnJobFailureUserError":"[auser@example.mail.com]","notifiedOnJobFailurePlatformError":"[auser2@example.mail.com, auser@example.mail.com]","notifiedOnJobSuccess":"[auser@example.mail.com]","notifiedOnJobDeploy":"[auser2@example.mail.com, auser@example.mail.com]"}}},"..."]}, 
                total_items = 100, 
                total_pages = 5
            )
        else :
            return DataJobPage(
        )
        """

    def testDataJobPage(self):
        """Test DataJobPage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
